Objects can be created by calls of the form new("survCliques", ...).
alphas, zlist, cliques, cliquesLoadings.
Slots
.Data:
Object of class "list"
alphas:
Object of class "numeric". It contains
pvalues of the cliques.
zlist:
Object of class "list". For each
cliques, the list of pvalues for all the covariates.
cliques:
Object of class "list". The list of
the genes in the cliques.
coxObjs:
Object of class "list". For each
cliques, the object used for Coxph analysis.
cliquesLoadings:
Object of class "list". For each
cliques, the loadings as calculated by the PCA.
cliquesExpr:
Object of class "list". For each
cliques, the cliques expression.
Extends
Class "'>list", from data part.
Class "'>vector", by class "list", distance 2.
Class "'>Ulist", by class "list", distance 2.
Class "'>Uvector", by class "list", distance 3.
Methods
No methods defined with class "survCliques" in the signature.